==> Paws-0.04.tar.gz: Paws-0.04/lib/Paws/EC2/CancelImportTask.pm <==

package Paws::EC2::CancelImportTask {
  use Moose;
  has CancelReason => (is => 'ro', isa => 'Str');
  has DryRun => (is => 'ro', isa => 'Bool');
  has ImportTaskId => (is => 'ro', isa => 'Str');

  use MooseX::ClassAttribute;

  class_has _api_call => (isa => 'Str', is => 'ro', default => 'CancelImportTask');
  class_has _returns => (isa => 'Str', is => 'ro', default => 'Paws::EC2::CancelImportTaskResult');
  class_has _result_key => (isa => 'Str', is => 'ro');
}
1;

### main pod documentation begin ###

=head1 NAME

Paws::EC2::CancelImportTask - Arguments for method CancelImportTask on Paws::EC2

=head1 DESCRIPTION

This class represents the parameters used for calling the method CancelImportTask on the 
Amazon Elastic Compute Cloud service. Use the attributes of this class
as arguments to method CancelImportTask.

You shouln't make instances of this class. Each attribute should be used as a named argument in the call to CancelImportTask.

As an example:

  $service_obj->CancelImportTask(Att1 => $value1, Att2 => $value2, ...);

Values for attributes that are native types (Int, String, Float, etc) can passed as-is (scalar values). Values for complex Types (objects) can be passed as a HashRef. The keys and values of the hashref will be used to instance the underlying object.

=head1 ATTRIBUTES

=head2 CancelReason => Str

  

The reason for canceling the task.










=head2 DryRun => Bool

  

=head2 ImportTaskId => Str

  

The ID of the ImportImage or ImportSnapshot task to be cancelled.












=head1 SEE ALSO

This class forms part of L<Paws>, documenting arguments for method CancelImportTask in L<Paws::EC2>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: https://github.com/pplu/aws-sdk-perl

Please report bugs to: https://github.com/pplu/aws-sdk-perl/issues

=cut

==> Paws-0.08.tar.gz: Paws-0.08/lib/Paws/EC2/CancelImportTask.pm <==

package Paws::EC2::CancelImportTask {
  use Moose;
  has CancelReason => (is => 'ro', isa => 'Str');
  has DryRun => (is => 'ro', isa => 'Bool');
  has ImportTaskId => (is => 'ro', isa => 'Str');

  use MooseX::ClassAttribute;

  class_has _api_call => (isa => 'Str', is => 'ro', default => 'CancelImportTask');
  class_has _returns => (isa => 'Str', is => 'ro', default => 'Paws::EC2::CancelImportTaskResult');
  class_has _result_key => (isa => 'Str', is => 'ro');
}
1;

### main pod documentation begin ###

=head1 NAME

Paws::EC2::CancelImportTask - Arguments for method CancelImportTask on Paws::EC2

=head1 DESCRIPTION

This class represents the parameters used for calling the method CancelImportTask on the 
Amazon Elastic Compute Cloud service. Use the attributes of this class
as arguments to method CancelImportTask.

You shouln't make instances of this class. Each attribute should be used as a named argument in the call to CancelImportTask.

As an example:

  $service_obj->CancelImportTask(Att1 => $value1, Att2 => $value2, ...);

Values for attributes that are native types (Int, String, Float, etc) can passed as-is (scalar values). Values for complex Types (objects) can be passed as a HashRef. The keys and values of the hashref will be used to instance the underlying object.

=head1 ATTRIBUTES

=head2 CancelReason => Str

  

The reason for canceling the task.










=head2 DryRun => Bool

  

Checks whether you have the required permissions for the action,
without actually making the request, and provides an error response. If
you have the required permissions, the error response is
C<DryRunOperation>. Otherwise, it is C<UnauthorizedOperation>.










=head2 ImportTaskId => Str

  

The ID of the import image or import snapshot task to be canceled.












=head1 SEE ALSO

This class forms part of L<Paws>, documenting arguments for method CancelImportTask in L<Paws::EC2>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: https://github.com/pplu/aws-sdk-perl

Please report bugs to: https://github.com/pplu/aws-sdk-perl/issues

=cut
